diff --git a/app/addons/stripe_connect/Tygh/Addons/StripeConnect/Payments/StripeConnect.php b/app/addons/stripe_connect/Tygh/Addons/StripeConnect/Payments/StripeConnect.php
index 5fd8163db11..6cc9c5e98d1 100644
--- a/app/addons/stripe_connect/Tygh/Addons/StripeConnect/Payments/StripeConnect.php
+++ b/app/addons/stripe_connect/Tygh/Addons/StripeConnect/Payments/StripeConnect.php
@@ -35,6 +35,7 @@
 use Tygh\Addons\StripeConnect\StripeException;
 use Tygh\Enum\OrderStatuses;
 use Tygh\Enum\YesNo;
+use Tygh\Registry;
 
 /**
  * Class StripeConnect implements Stipe Connect payment method.
@@ -269,7 +270,7 @@ public function chargeWithout3DSecure(array $order_info)
 
         // Check that all receivers are valid accounts
         if (!$this->validateOrdersQueueReceivers($orders_queue)) {
-            $pp_response['order_status'] = 'F';
+            $pp_response['order_status'] = OrderStatuses::FAILED;
 
             return $pp_response;
         }
@@ -316,8 +317,8 @@ public function chargeWithout3DSecure(array $order_info)
                 if (!$withdrawal) {
                     continue;
                 }
-                $payouts_manager->createWithdrawal($withdrawal, $order_id);
 
+                $payouts_manager->createWithdrawal($withdrawal, $order_id, $this->getWithdrawalDescription($order_id, $company_id, $charge->metadata['stripe_fee']));
 
                 if (!$this->addon_settings['collect_payouts']) {
                     continue;
@@ -329,9 +330,9 @@ public function chargeWithout3DSecure(array $order_info)
                 $charge->capture();
             }
 
-            $pp_response['order_status'] = 'P';
+            $pp_response['order_status'] = OrderStatuses::PAID;
         } catch (Exception $e) {
-            $pp_response['order_status'] = 'F';
+            $pp_response['order_status'] = OrderStatuses::FAILED;
             $pp_response['reason_text'] = $e->getMessage();
 
             foreach ($charges_to_capture as $charge) {
@@ -660,8 +661,10 @@ protected function transferFunds(array $order_info, PayoutsManager $payouts_mana
             return null;
         }
 
+        $formatted_accounting_withdrawal = $this->formatAmount($accounting_withdrawal);
         $receiver = static::getChargeReceiver($order_info['company_id']);
         $description = $this->getWithdrawalDescription($order_info['order_id'], $order_info['company_id']);
+        $stripe_fee = $formatted_accounting_withdrawal - $transfer_amount;
 
         $transfer_params = [
             'currency'           => $this->processor_params['currency'],
@@ -675,6 +678,10 @@ protected function transferFunds(array $order_info, PayoutsManager $payouts_mana
             'source_transaction' => $charge->id,
         ];
 
+        if ($stripe_fee > 0) {
+            $transfer_params['metadata']['stripe_fee'] = $stripe_fee;
+        }
+
         try {
             $transfer = Transfer::create($transfer_params);
         } catch (Exception $e) {
@@ -690,12 +697,13 @@ protected function transferFunds(array $order_info, PayoutsManager $payouts_mana
     /**
      * Provides description for withdrawal.
      *
-     * @param int $order_id
-     * @param int $company_id
+     * @param int $order_id   Order ID
+     * @param int $company_id Company ID
+     * @param int $stripe_fee Stripe fee
      *
      * @return string
      */
-    protected function getWithdrawalDescription($order_id, $company_id)
+    protected function getWithdrawalDescription($order_id, $company_id, $stripe_fee = 0)
     {
         $lang_code = fn_get_company_language($company_id);
 
@@ -707,6 +715,24 @@ protected function getWithdrawalDescription($order_id, $company_id)
             $lang_code
         );
 
+        if ($stripe_fee > 0) {
+            $currency = $this->processor_params['currency'];
+            $currencies = Registry::get('currencies');
+            $stripe_fee = round($stripe_fee / 100, 2);
+
+            if (!empty($currencies[$currency])) {
+                $symbol = $currencies[$currency]['symbol'];
+
+                if (YesNo::isTrue($currencies[$currency]['after'])) {
+                    $stripe_fee = $stripe_fee . $symbol;
+                } else {
+                    $stripe_fee = $symbol . $stripe_fee;
+                }
+            }
+
+            $description .= '. ' . __('stripe_connect.stripe_commission_included', ['[fee]' =>  $stripe_fee]);
+        }
+
         return $description;
     }
 
@@ -789,9 +815,13 @@ protected function chargeCustomer(array $order_info, Customer $customer, Payouts
 
         if ($order_info['company_id'] && empty($order_info['use_gift_certificates'])) {
             $receiver = static::getChargeReceiver($order_info['company_id']);
-            list($accounting_withdrawal,, $application_fee) = $this->getWithdrawalAmount($order_info, $payouts_manager);
+            list($accounting_withdrawal, $transfer_amount, $application_fee) = $this->getWithdrawalAmount($order_info, $payouts_manager);
             $params['application_fee'] = $application_fee;
             $params['metadata']['withdrawal'] = $accounting_withdrawal;
+            $stripe_fee = $this->formatAmount($accounting_withdrawal) - $transfer_amount;
+            if ($stripe_fee > 0) {
+                $params['metadata']['stripe_fee'] = $stripe_fee;
+            }
 
             // payment receiver must be specified in options to perform Direct charge
             $options = ['stripe_account' => $receiver];
@@ -998,7 +1028,7 @@ protected function transferFundsToVendors(array $orders, Charge $charge)
                 continue;
             }
 
-            $payouts_manager->createWithdrawal($withdrawal, $order_id);
+            $payouts_manager->createWithdrawal($withdrawal, $order_id, $this->getWithdrawalDescription($order_id, $company_id, $transfer->metadata['stripe_fee']));
             if (!$this->addon_settings['collect_payouts']) {
                 continue;
             }
diff --git a/var/langs/en/addons/stripe_connect.po b/var/langs/en/addons/stripe_connect.po
index 2d4bbd6d2cd..750ff133c26 100644
--- a/var/langs/en/addons/stripe_connect.po
+++ b/var/langs/en/addons/stripe_connect.po
@@ -319,3 +319,7 @@ msgstr "Create Stripe Standard account"
 msgctxt "Languages::stripe_connect.currency.description"
 msgid "Stripe Connect requires the selected currency to have 2 decimals."
 msgstr "Stripe Connect requires the selected currency to have 2 decimals."
+
+msgctxt "Languages::stripe_connect.stripe_commission_included"
+msgid "Stripe commission included: [fee]"
+msgstr "Stripe commission included: [fee]"

diff --git a/app/addons/stripe_connect/Tygh/Addons/StripeConnect/PayoutsManager.php b/app/addons/stripe_connect/Tygh/Addons/StripeConnect/PayoutsManager.php
index e967a51e5c9..58ebb1ca033 100644
--- a/app/addons/stripe_connect/Tygh/Addons/StripeConnect/PayoutsManager.php
+++ b/app/addons/stripe_connect/Tygh/Addons/StripeConnect/PayoutsManager.php
@@ -40,22 +40,23 @@ public function __construct($company_id)
     /**
      * Creates withdrawal when an order is paid.
      *
      * @param float $amount   Withdrawal amount
      * @param int   $order_id Order ID
      *
      * @return int Withdrawal ID
      */
-    public function createWithdrawal($amount, $order_id)
+    public function createWithdrawal($amount, $order_id, $comment = '')
     {
-        $params = array(
+        $params = [
             'company_id'      => $this->company_id,
             'payout_type'     => VendorPayoutTypes::WITHDRAWAL,
             'approval_status' => VendorPayoutApprovalStatuses::COMPLETED,
             'payout_amount'   => $amount,
-            'comments'        => __('stripe_connect.withdrawal_for_the_order', array(
+            'comments'        => $comment ? $comment : __('stripe_connect.withdrawal_for_the_order', [
                 '[order_id]' => $order_id,
-            )),
-        );
+            ]),
+        ];
 
         return $this->manager->update($params);
     }
@@ -40,22 +40,23 @@ public function __construct($company_id)
      * Creates withdrawal when an order is paid.
      *
-     * @param float $amount   Withdrawal amount
-     * @param int   $order_id Order ID
+     * @param float  $amount   Withdrawal amount
+     * @param int    $order_id Order ID
+     * @param string $comment  Comment
      *
      * @return int Withdrawal ID